@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright (C) 2017-2020 Robby Stephenson <robby@periapsis.org>
+    Copyright (C) 2017-2021 Robby Stephenson <robby@periapsis.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -42,7 +42,8 @@
 #include <QLabel>
 #include <QFile>
 #include <QTextStream>
-#include <QVBoxLayout>
+#include <QGridLayout>
+#include <QSpinBox>
 #include <QUrlQuery>
 #include <QJsonDocument>
 #include <QJsonObject>
@@ -52,13 +53,18 @@
 namespace {
   static const char* KINOPOISK_SEARCH_URL = "https://www.kinopoisk.ru/index.php";
   static const char* KINOPOISK_IMAGE_SIZE = "300x450";
+  static const char* KINOPOISK_API_FILM_URL  = "https://kinopoiskapiunofficial.tech/api/v2.2/films/";
+  static const char* KINOPOISK_API_STAFF_URL = "https://kinopoiskapiunofficial.tech/api/v1/staff";
+  static const char* KINOPOISK_API_KEY = "9ca8395a794fb28b82e01120a6968bbf03651271fd9ce5d5371a096d4f7dc7a3caa8361ba8914425a1c5c0f4f5d88dbd3d0fccaa781ca18cd4b2b587ebdeaac89cfa771622162a12";
+  static const int KINOPOISK_DEFAULT_CAST_SIZE = 10;
 }
 
 using namespace Tellico;
 using Tellico::Fetch::KinoPoiskFetcher;
 
 KinoPoiskFetcher::KinoPoiskFetcher(QObject* parent_)
-    : Fetcher(parent_), m_started(false) {
+    : Fetcher(parent_), m_started(false), m_redirected(false), m_numCast(KINOPOISK_DEFAULT_CAST_SIZE) {
+  m_apiKey = Tellico::reverseObfuscate(KINOPOISK_API_KEY);
 }
 
 KinoPoiskFetcher::~KinoPoiskFetcher() {
@@ -77,11 +83,13 @@ bool KinoPoiskFetcher::canSearch(Fetch::FetchKey k) const {
 }
 
 void KinoPoiskFetcher::readConfigHook(const KConfigGroup& config_) {
-  Q_UNUSED(config_);
+  m_numCast = config_.readEntry("Max Cast", KINOPOISK_DEFAULT_CAST_SIZE);
 }
 
 void KinoPoiskFetcher::search() {
   m_started = true;
+  m_redirected = false;
+  m_redirectUrl.clear();
   m_matches.clear();
 
   QUrl u(QString::fromLatin1(KINOPOISK_SEARCH_URL));
@@ -105,6 +113,8 @@ void KinoPoiskFetcher::search() {
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job.data(), &KJob::result, this, &KinoPoiskFetcher::slotComplete);
+  connect(m_job.data(), &KIO::TransferJob::redirection,
+          this, &KinoPoiskFetcher::slotRedirection);
 }
 
 void KinoPoiskFetcher::stop() {
@@ -120,6 +130,14 @@ void KinoPoiskFetcher::stop() {
   emit signalDone(this);
 }
 
+void KinoPoiskFetcher::slotRedirection(KIO::Job*, const QUrl& toUrl_) {
+  if(m_redirectUrl.isEmpty()) {
+    myDebug() << "Redirected to" << toUrl_;
+    m_redirectUrl = toUrl_;
+  }
+  m_redirected = true;
+}
+
 void KinoPoiskFetcher::slotComplete(KJob*) {
   if(m_job->error()) {
     m_job->uiDelegate()->showErrorMessage();
@@ -146,6 +164,13 @@ void KinoPoiskFetcher::slotComplete(KJob*) {
   f.close();
 #endif
 
+  if(m_started && m_redirected) {
+    // don't pull the data here, just add it to a single response
+    auto res = new FetchResult(this, request().value(), QString());
+    m_matches.insert(res->uid, m_redirectUrl);
+    emit signalResultFound(res);
+  }
+
   // look for a paragraph, class=",", with an internal /ink to "/level/1/film..."
   QRegularExpression resultRx(QStringLiteral("<p class=\"name\">\\s*"
                                              "<a href=\"/film[^\"]+\".*? data-url=\"([^\"]*)\".*?>(.*?)</a>\\s*"
@@ -153,7 +178,7 @@ void KinoPoiskFetcher::slotComplete(KJob*) {
 
   QString href, title, year;
   QRegularExpressionMatchIterator i = resultRx.globalMatch(output);
-  while(m_started && i.hasNext()) {
+  while(m_started && !m_redirected && i.hasNext()) {
     QRegularExpressionMatch match = i.next();
     href = match.captured(1);
     title = match.captured(2);
@@ -162,9 +187,9 @@ void KinoPoiskFetcher::slotComplete(KJob*) {
       QUrl url(QString::fromLatin1(KINOPOISK_SEARCH_URL));
       url = url.resolved(QUrl(href));
 //      myDebug() << url << title << year;
-      FetchResult* r = new FetchResult(this, title, year);
-      m_matches.insert(r->uid, url);
-      emit signalResultFound(r);
+      auto res = new FetchResult(this, title, year);
+      m_matches.insert(res->uid, url);
+      emit signalResultFound(res);
     }
   }
 
@@ -200,7 +225,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::fetchEntryHook(uint uid_) {
   const QByteArray data = getJob->data();
   const QString results = Tellico::decodeHTML(Tellico::fromHtmlData(data, "UTF-8"));
   if(results.isEmpty()) {
-    myDebug() << "no text results";
+    myDebug() << "KinoPoiskFetcher: no text results";
     return Data::EntryPtr();
   }
 
@@ -216,14 +241,23 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::fetchEntryHook(uint uid_) {
   f.close();
 #endif
 
-  entry = parseEntry(results);
-  if(!entry) {
-    // might want to check LD+JSON format
-    myDebug() << "...trying Linked Data";
-    entry = parseEntryLinkedData(results);
+  if(results.contains(QStringLiteral("captcha"))) {
+//    myDebug() << "KinoPoiskFetcher: captcha triggered";
+    static const QRegularExpression re(QLatin1String("/(\\d+)"));
+    QRegularExpressionMatch match = re.match(url.url());
+    if(match.hasMatch()) {
+      entry = requestEntry(match.captured(1));
+    }
+  } else {
+    entry = parseEntry(results);
+    if(!entry) {
+      // might want to check LD+JSON format
+//      myDebug() << "...trying Linked Data";
+      entry = parseEntryLinkedData(results);
+    }
   }
   if(!entry) {
-    myDebug() << "No discernible entry data";
+//    myDebug() << "No discernible entry data";
     return Data::EntryPtr();
   }
 
@@ -249,8 +283,133 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::fetchEntryHook(uint uid_) {
   return entry;
 }
 
+Tellico::Data::EntryPtr KinoPoiskFetcher::requestEntry(const QString& filmId_) {
+  QUrl url(QLatin1String(KINOPOISK_API_FILM_URL) + filmId_);
+
+  QPointer<KIO::StoredTransferJob> getJob = KIO::storedGet(url, KIO::NoReload, KIO::HideProgressInfo);
+  getJob->addMetaData(QStringLiteral("content-type"), QStringLiteral("application/json"));
+  getJob->addMetaData(QStringLiteral("customHTTPHeader"), QStringLiteral("X-API-KEY: ") + m_apiKey);
+  KJobWidgets::setWindow(getJob, GUI::Proxy::widget());
+  if(!getJob->exec()) {
+    myWarning() << "unable to read" << url;
+    return Data::EntryPtr();
+  }
+
+  QByteArray data = getJob->data();
+#if 0
+  myDebug() << url;
+  myWarning() << "Remove json debug from kinopoiskfetcher.cpp";
+  QFile file(QString::fromLatin1("/tmp/test-kinopoisk.json"));
+  if(file.open(QIODevice::WriteOnly)) {
+    QTextStream t(&file);
+    t.setCodec("UTF-8");
+    t << data;
+  }
+  file.close();
+#endif
+
+  Data::CollPtr coll(new Data::VideoCollection(true));
+  Data::EntryPtr entry(new Data::Entry(coll));
+  coll->addEntries(entry);
+
+  QJsonDocument doc = QJsonDocument::fromJson(data);
+  const QVariantMap resultMap = doc.object().toVariantMap();
+
+  entry->setField(QStringLiteral("title"), mapValue(resultMap, "nameRu"));
+  entry->setField(QStringLiteral("year"), mapValue(resultMap, "year"));
+  entry->setField(QStringLiteral("nationality"), mapValue(resultMap, "countries", "country"));
+  entry->setField(QStringLiteral("genre"), mapValue(resultMap, "genres", "genre"));
+  entry->setField(QStringLiteral("running-time"), mapValue(resultMap, "filmLength"));
+  entry->setField(QStringLiteral("plot"), mapValue(resultMap, "description"));
+  entry->setField(QStringLiteral("cover"), mapValue(resultMap, "posterUrl"));
+
+  const QString cert(QStringLiteral("certification"));
+  auto certField = coll->fieldByName(cert);
+  if(certField) {
+    entry->setField(cert, mpaaRating(mapValue(resultMap, "ratingMpaa"), certField->allowed()));
+  }
+
+  const QString imdb(QStringLiteral("imdb"));
+  const QString imdbId = mapValue(resultMap, "imdbId");
+  if(optionalFields().contains(imdb) && !imdbId.isEmpty()) {
+    coll->addField(Data::Field::createDefaultField(Data::Field::ImdbField));
+    entry->setField(imdb, QStringLiteral("https://www.imdb.com/title/") + imdbId);
+  }
+  const QString origTitle(QStringLiteral("origtitle"));
+  if(optionalFields().contains(origTitle)) {
+    if(!coll->hasField(origTitle)) {
+      Data::FieldPtr f(new Data::Field(origTitle, i18n("Original Title")));
+      f->setFormatType(FieldFormat::FormatTitle);
+      coll->addField(f);
+    }
+    entry->setField(origTitle, mapValue(resultMap, "nameOriginal"));
+  }
+
+  url = QUrl(QLatin1String(KINOPOISK_API_STAFF_URL));
+  QUrlQuery q;
+  q.addQueryItem(QStringLiteral("filmId"), filmId_);
+  url.setQuery(q);
+
+  getJob = KIO::storedGet(url, KIO::NoReload, KIO::HideProgressInfo);
+  getJob->addMetaData(QStringLiteral("content-type"), QStringLiteral("application/json"));
+  getJob->addMetaData(QStringLiteral("customHTTPHeader"), QStringLiteral("X-API-KEY: ") + m_apiKey);
+  KJobWidgets::setWindow(getJob, GUI::Proxy::widget());
+  if(!getJob->exec()) {
+    myWarning() << "unable to read" << url;
+    return Data::EntryPtr();
+  }
+
+  data = getJob->data();
+#if 0
+  myDebug() << url;
+  myWarning() << "Remove json2 debug from kinopoiskfetcher.cpp";
+  QFile file2(QString::fromLatin1("/tmp/test-kinopoisk-staff.json"));
+  if(file2.open(QIODevice::WriteOnly)) {
+    QTextStream t(&file2);
+    t.setCodec("UTF-8");
+    t << data;
+  }
+  file2.close();
+#endif
+
+  QStringList directors, writers, actors, producers, composers;
+
+  const auto staffArray = QJsonDocument::fromJson(data).array();
+  const int sz = staffArray.size();
+  for(int i = 0; i < sz; ++i) {
+    const auto obj = staffArray.at(i).toObject().toVariantMap();
+    const QString key = mapValue(obj, "professionKey");
+    QString name = mapValue(obj, "nameRu");
+    if(name.isEmpty()) name = mapValue(obj, "nameEn");
+    if(name.isEmpty()) continue;
+    if(key == QLatin1String("DIRECTOR")) {
+      directors += name;
+    } else if(key == QLatin1String("ACTOR")) {
+      if(actors.size() < m_numCast) {
+        actors += (name + FieldFormat::columnDelimiterString() + mapValue(obj, "description"));
+      }
+    } else if(key == QLatin1String("WRITER")) {
+      writers += name;
+    } else if(key == QLatin1String("PRODUCER")) {
+      producers += name;
+    } else if(key == QLatin1String("COMPOSER")) {
+      composers += name;
+    } else {
+//      myDebug() << "...skipping" << key;
+    }
+  }
+
+  entry->setField(QStringLiteral("director"), directors.join(Tellico::FieldFormat::delimiterString()));
+  entry->setField(QStringLiteral("writer"), writers.join(Tellico::FieldFormat::delimiterString()));
+  entry->setField(QStringLiteral("producer"), producers.join(Tellico::FieldFormat::delimiterString()));
+  entry->setField(QStringLiteral("composer"), composers.join(Tellico::FieldFormat::delimiterString()));
+  entry->setField(QStringLiteral("cast"), actors.join(Tellico::FieldFormat::rowDelimiterString()));
+
+  return entry;
+}
+
 Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
-  QRegularExpression jsonRx(QStringLiteral("<script.*?type=\"application/json\">(.+?)</script>"));
+  static const QRegularExpression jsonRx(QStringLiteral("<script.*?type=\"application/json\".*?>(.+?)</script>"));
   QRegularExpressionMatch jsonMatch = jsonRx.match(str_);
   if(!jsonMatch.hasMatch()) {
     myDebug() << "No JSON data";
@@ -323,7 +482,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
 }
 
 Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntryLinkedData(const QString& str_) {
-  QRegularExpression jsonRx(QStringLiteral("<script.*?type=\"application/ld\\+json\">(.+?)</script>"));
+  QRegularExpression jsonRx(QStringLiteral("<script.*?type=\"application/ld\\+json\".*?>(.+?)</script>"));
   QRegularExpressionMatch jsonMatch = jsonRx.match(str_);
   if(!jsonMatch.hasMatch()) {
     myDebug() << "No JSON data";
@@ -422,7 +581,11 @@ QString KinoPoiskFetcher::fieldValueFromObject(const QJsonObject& obj_, const QS
     return value_.toString();
   }
 
-  QJsonObject valueObj = obj_.value(value_.toObject().value(QStringLiteral("id")).toString()).toObject();
+  QJsonObject valueObj = value_.toObject();
+  // if there's a reference to another object, need to pull it from the higher level data object
+  if(valueObj.contains(QStringLiteral("__ref"))) {
+    valueObj = obj_.value(valueObj.value(QStringLiteral("__ref")).toString()).toObject();
+  }
 
   // if it has a 'person' field, gotta grab the person name
   if(valueObj.contains(QLatin1String("person"))) {
@@ -430,7 +593,7 @@ QString KinoPoiskFetcher::fieldValueFromObject(const QJsonObject& obj_, const QS
   }
 
   if(field_ == QLatin1String("title")) {
-    QString title = valueObj.value(QStringLiteral("russian")).toString();
+    const QString title = valueObj.value(QStringLiteral("russian")).toString();
     // return original if russian is not available
     return title.isEmpty() ? valueObj.value(QStringLiteral("original")).toString() : title;
   } else if(field_ == QLatin1String("origtitle")) {
@@ -444,21 +607,7 @@ QString KinoPoiskFetcher::fieldValueFromObject(const QJsonObject& obj_, const QS
     url.append(QLatin1Char('/') + QLatin1String(KINOPOISK_IMAGE_SIZE));
     return url;
   } else if(field_ == QLatin1String("certification")) {
-    Q_ASSERT(allowed_.size() == 5);
-    // default collection has 5 MPAA values
-    if(allowed_.size() != 5) return QString();
-    const QString mpaa = valueObj.value(QLatin1String("mpaa")).toString();
-    if(mpaa == QLatin1String("g")) {
-      return allowed_.at(0);
-    } else if(mpaa == QLatin1String("pg")) {
-      return allowed_.at(1);
-    } else if(mpaa == QLatin1String("pg13")) {
-      return allowed_.at(2);
-    } else if(mpaa == QLatin1String("r")) {
-      return allowed_.at(3);
-    } else {
-      return allowed_.at(4);
-    }
+    return mpaaRating(valueObj.value(QLatin1String("mpaa")).toString(), allowed_);
   // with an 'originalName' or 'name' field return that
   // and check this before comparing against field names for people, like 'director'
   } else if(valueObj.contains(QLatin1String("originalName")) || valueObj.contains(QLatin1String("name"))) {
@@ -481,6 +630,22 @@ QString KinoPoiskFetcher::fieldValueFromObject(const QJsonObject& obj_, const QS
   return QString();
 }
 
+QString KinoPoiskFetcher::mpaaRating(const QString& value_, const QStringList& allowed_) {
+  // default collection has 5 MPAA values
+  if(allowed_.size() != 5) return value_;
+  if(value_ == QLatin1String("g")) {
+    return allowed_.at(0);
+  } else if(value_ == QLatin1String("pg")) {
+    return allowed_.at(1);
+  } else if(value_ == QLatin1String("pg13")) {
+    return allowed_.at(2);
+  } else if(value_ == QLatin1String("r")) {
+    return allowed_.at(3);
+  } else {
+    return allowed_.at(4);
+  }
+}
+
 Tellico::Fetch::FetchRequest KinoPoiskFetcher::updateRequest(Data::EntryPtr entry_) {
   QString t = entry_->field(QStringLiteral("title"));
   if(!t.isEmpty()) {
@@ -503,20 +668,50 @@ QString KinoPoiskFetcher::defaultIcon() {
 
 Tellico::StringHash KinoPoiskFetcher::allOptionalFields() {
   StringHash hash;
-  hash[QStringLiteral("origtitle")] = i18n("Original Title");
   hash[QStringLiteral("kinopoisk")] = i18n("KinoPoisk Link");
+  hash[QStringLiteral("imdb")] = i18n("IMDb Link");
+  hash[QStringLiteral("origtitle")] = i18n("Original Title");
   return hash;
 }
 
 KinoPoiskFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const KinoPoiskFetcher* fetcher_)
     : Fetch::ConfigWidget(parent_) {
-  QVBoxLayout* l = new QVBoxLayout(optionsWidget());
-  l->addWidget(new QLabel(i18n("This source has no options."), optionsWidget()));
-  l->addStretch();
+  QGridLayout* l = new QGridLayout(optionsWidget());
+  l->setSpacing(4);
+  l->setColumnStretch(1, 10);
+
+  int row = -1;
+
+  QLabel* label = new QLabel(i18n("&Maximum cast: "), optionsWidget());
+  l->addWidget(label, ++row, 0);
+  m_numCast = new QSpinBox(optionsWidget());
+  m_numCast->setMaximum(99);
+  m_numCast->setMinimum(0);
+  m_numCast->setValue(KINOPOISK_DEFAULT_CAST_SIZE);
+#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
+  void (QSpinBox::* textChanged)(const QString&) = &QSpinBox::valueChanged;
+#else
+  void (QSpinBox::* textChanged)(const QString&) = &QSpinBox::textChanged;
+#endif
+  connect(m_numCast, textChanged, this, &ConfigWidget::slotSetModified);
+  l->addWidget(m_numCast, row, 1);
+  QString w = i18n("The list of cast members may include many people. Set the maximum number returned from the search.");
+  label->setWhatsThis(w);
+  m_numCast->setWhatsThis(w);
+  label->setBuddy(m_numCast);
+
+  l->setRowStretch(++row, 10);
 
   addFieldsWidget(KinoPoiskFetcher::allOptionalFields(), fetcher_ ? fetcher_->optionalFields() : QStringList());
+  if(fetcher_) {
+    m_numCast->setValue(fetcher_->m_numCast);
+  }
 }
 
 QString KinoPoiskFetcher::ConfigWidget::preferredName() const {
   return KinoPoiskFetcher::defaultName();
 }
+
+void KinoPoiskFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
+  config_.writeEntry("Max Cast", m_numCast->value());
+}
