@@ -38,6 +38,7 @@ class KJob;
 namespace KIO {
   class StoredTransferJob;
 }
+class OMDBFetcherTest;
 
 namespace Tellico {
 
@@ -99,6 +100,7 @@ private Q_SLOTS:
   void slotComplete(KJob* job);
 
 private:
+  friend class ::OMDBFetcherTest;
   virtual void search() Q_DECL_OVERRIDE;
   virtual FetchRequest updateRequest(Data::EntryPtr entry) Q_DECL_OVERRIDE;
   void populateEntry(Data::EntryPtr entry, const QVariantMap& resultMap, bool fullData);
