@@ -63,7 +63,7 @@ QString SpringerFetcher::attribution() const {
               QLatin1String("https://dev.springernature.com/"));
 }
 
-bool SpringerFetcher::canSearch(FetchKey k) const  {
+bool SpringerFetcher::canSearch(Fetch::FetchKey k) const  {
   return k == Title || k == Person || k == Keyword || k == ISBN || k == DOI || k == Raw;
 }
 
@@ -86,34 +86,34 @@ QUrl SpringerFetcher::searchUrl() {
   q.addQueryItem(QStringLiteral("s"), QString::number(m_start + 1));
   q.addQueryItem(QStringLiteral("p"), QString::number(SPRINGER_QUERY_COUNT));
 
-  switch(request().key) {
+  switch(request().key()) {
     case Title:
-      q.addQueryItem(QStringLiteral("q"), QStringLiteral("title:\"%1\" OR book:\"%1\"").arg(request().value));
+      q.addQueryItem(QStringLiteral("q"), QStringLiteral("title:\"%1\" OR book:\"%1\"").arg(request().value()));
       break;
 
     case Person:
-      q.addQueryItem(QStringLiteral("q"), QStringLiteral("name:%1").arg(request().value));
+      q.addQueryItem(QStringLiteral("q"), QStringLiteral("name:%1").arg(request().value()));
       break;
 
     case Keyword:
-      q.addQueryItem(QStringLiteral("q"), QStringLiteral("\"%1\"").arg(request().value));
+      q.addQueryItem(QStringLiteral("q"), QStringLiteral("\"%1\"").arg(request().value()));
       break;
 
     case ISBN:
       {
         // only grab first value
-        QString v = request().value.section(QLatin1Char(';'), 0);
+        QString v = request().value().section(QLatin1Char(';'), 0);
         v = ISBNValidator::isbn13(v);
         q.addQueryItem(QStringLiteral("q"), QStringLiteral("isbn:%1").arg(v));
       }
       break;
 
     case DOI:
-      q.addQueryItem(QStringLiteral("q"), QStringLiteral("doi:%1").arg(request().value));
+      q.addQueryItem(QStringLiteral("q"), QStringLiteral("doi:%1").arg(request().value()));
       break;
 
     case Raw:
-      q.addQueryItem(QStringLiteral("q"), request().value);
+      q.addQueryItem(QStringLiteral("q"), request().value());
       break;
 
     default:
@@ -174,7 +174,7 @@ QString SpringerFetcher::defaultName() {
 }
 
 QString SpringerFetcher::defaultIcon() {
-  return favIcon("http://www.springerlink.com");
+  return favIcon("https://link.springer.com/static/sites/link/images/favicon-32x32.png");
 }
 
 SpringerFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const SpringerFetcher* fetcher_)
