@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright (C) 2017 Robby Stephenson <robby@periapsis.org>
+    Copyright (C) 2017-2021 Robby Stephenson <robby@periapsis.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -27,6 +27,7 @@
 #include "../translators/tellicoimporter.h"
 #include "../utils/string_utils.h"
 #include "../core/tellico_strings.h"
+#include "../gui/combobox.h"
 #include "../tellico_debug.h"
 
 #include <KLocalizedString>
@@ -35,7 +36,7 @@
 #include <QLabel>
 #include <QFile>
 #include <QTextStream>
-#include <QVBoxLayout>
+#include <QGridLayout>
 #include <QTextCodec>
 #include <QUrlQuery>
 
@@ -43,15 +44,15 @@ namespace {
   // a lot of overlap with boardgamegeekimporter.h
   static const int BGG_MAX_RETURNS_TOTAL = 10;
   // interchangeable with boardgamegeek.com
-  static const char* BGG_SEARCH_URL  = "http://videogamegeek.com/xmlapi2/search";
-  static const char* BGG_THING_URL  = "http://videogamegeek.com/xmlapi2/thing";
+  static const char* BGG_SEARCH_URL  = "https://videogamegeek.com/xmlapi2/search";
+  static const char* BGG_THING_URL  = "https://videogamegeek.com/xmlapi2/thing";
 }
 
 using namespace Tellico;
 using Tellico::Fetch::VideoGameGeekFetcher;
 
 VideoGameGeekFetcher::VideoGameGeekFetcher(QObject* parent_)
-    : XMLFetcher(parent_) {
+    : XMLFetcher(parent_), m_imageSize(SmallImage) {
   setLimit(BGG_MAX_RETURNS_TOTAL);
   setXSLTFilename(QStringLiteral("boardgamegeek2tellico.xsl"));
 }
@@ -65,7 +66,7 @@ QString VideoGameGeekFetcher::source() const {
 
 // https://boardgamegeek.com/wiki/page/XML_API_Terms_of_Use
 QString VideoGameGeekFetcher::attribution() const {
-  return i18n(providedBy).arg(QLatin1String("https://boardgamegeek.com"), QLatin1String("BoardGameGeek"));
+  return i18n(providedBy, QLatin1String("https://boardgamegeek.com"), QLatin1String("BoardGameGeek"));
 }
 
 bool VideoGameGeekFetcher::canSearch(Fetch::FetchKey k) const {
@@ -76,6 +77,13 @@ bool VideoGameGeekFetcher::canFetch(int type) const {
   return type == Data::Collection::Game;
 }
 
+void VideoGameGeekFetcher::readConfigHook(const KConfigGroup& config_) {
+  const int imageSize = config_.readEntry("Image Size", -1);
+  if(imageSize > -1) {
+    m_imageSize = static_cast<ImageSize>(imageSize);
+  }
+}
+
 QUrl VideoGameGeekFetcher::searchUrl() {
   QUrl u(QString::fromLatin1(BGG_SEARCH_URL));
 
@@ -138,11 +146,13 @@ Tellico::Data::EntryPtr VideoGameGeekFetcher::fetchEntryHookData(Data::EntryPtr
   f.close();
 #endif
 
-  Import::TellicoImporter imp(xsltHandler()->applyStylesheet(output));
+  auto handler = xsltHandler();
+  handler->addStringParam("image-size", QByteArray::number(m_imageSize));
+
+  Import::TellicoImporter imp(handler->applyStylesheet(output));
   // be quiet when loading images
   imp.setOptions(imp.options() ^ Import::ImportShowImageErrors);
   Data::CollPtr coll = imp.collection();
-//  getTracks(entry);
   if(!coll) {
     myWarning() << "no collection pointer";
     return entry_;
@@ -194,15 +204,38 @@ Tellico::StringHash VideoGameGeekFetcher::allOptionalFields() {
 
 VideoGameGeekFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const VideoGameGeekFetcher* fetcher_)
     : Fetch::ConfigWidget(parent_) {
-  QVBoxLayout* l = new QVBoxLayout(optionsWidget());
-  l->addWidget(new QLabel(i18n("This source has no options."), optionsWidget()));
-  l->addStretch();
+  QGridLayout* l = new QGridLayout(optionsWidget());
+  l->setSpacing(4);
+  l->setColumnStretch(1, 10);
+
+  int row = -1;
+
+  QLabel* label = new QLabel(i18n("&Image size: "), optionsWidget());
+  l->addWidget(label, ++row, 0);
+  m_imageCombo = new GUI::ComboBox(optionsWidget());
+  m_imageCombo->addItem(i18n("No Image"), NoImage);
+  m_imageCombo->addItem(i18n("Small Image"), SmallImage);
+  m_imageCombo->addItem(i18n("Large Image"), LargeImage);
+  void (GUI::ComboBox::* activatedInt)(int) = &GUI::ComboBox::activated;
+  connect(m_imageCombo, activatedInt, this, &ConfigWidget::slotSetModified);
+  l->addWidget(m_imageCombo, row, 1);
+  label->setBuddy(m_imageCombo);
+
+  l->setRowStretch(++row, 10);
 
   // now add additional fields widget
   addFieldsWidget(VideoGameGeekFetcher::allOptionalFields(), fetcher_ ? fetcher_->optionalFields() : QStringList());
+
+  if(fetcher_) {
+    m_imageCombo->setCurrentData(fetcher_->m_imageSize);
+  } else { // defaults
+    m_imageCombo->setCurrentData(SmallImage);
+  }
 }
 
-void VideoGameGeekFetcher::ConfigWidget::saveConfigHook(KConfigGroup&) {
+void VideoGameGeekFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
+  const int n = m_imageCombo->currentData().toInt();
+  config_.writeEntry("Image Size", n);
 }
 
 QString VideoGameGeekFetcher::ConfigWidget::preferredName() const {
