@@ -215,7 +215,7 @@ FetchDialog::FetchDialog(QWidget* parent_)
   connect(m_editISBN, &QAbstractButton::clicked, this, &FetchDialog::slotEditMultipleISBN);
 
   // add for spacing
-  box2HBoxLayout->setStretchFactor(new QWidget(box2), 10);
+  box2HBoxLayout->addStretch(10);
 
   label = new QLabel(i18n("Search s&ource:"), box2);
   box2HBoxLayout->addWidget(label);
@@ -409,7 +409,8 @@ void FetchDialog::slotSearchClicked() {
     qApp->processEvents();
     Fetch::Manager::self()->startSearch(m_sourceCombo->currentText(),
                                         static_cast<Fetch::FetchKey>(m_keyCombo->currentData().toInt()),
-                                        value);
+                                        value,
+                                        Data::Document::self()->collection()->type());
   }
 }
 
@@ -659,7 +660,7 @@ void FetchDialog::slotInit() {
   KConfigGroup config(KSharedConfig::openConfig(), "Fetch Dialog Options");
   KWindowConfig::restoreWindowSize(windowHandle(), config);
 
-  if(!Fetch::Manager::self()->canFetch()) {
+  if(!Fetch::Manager::self()->canFetch(Data::Document::self()->collection()->type())) {
     m_searchButton->setEnabled(false);
     Kernel::self()->sorry(i18n("No Internet sources are available for your current collection type."), this);
   }
@@ -881,7 +882,7 @@ void FetchDialog::slotResetCollection() {
     m_sourceCombo->addItem(Fetch::Manager::self()->fetcherIcon(fetcher.data()), fetcher->source());
   }
 
-  if(Fetch::Manager::self()->canFetch()) {
+  if(Fetch::Manager::self()->canFetch(Data::Document::self()->collection()->type())) {
     m_searchButton->setEnabled(true);
   } else {
     m_searchButton->setEnabled(false);
