@@ -28,6 +28,8 @@
 #include "fieldwidget.h"
 #include "../datavectors.h"
 
+class FieldWidgetTest;
+
 namespace Tellico {
   namespace GUI {
     class LineEdit;
@@ -38,6 +40,8 @@ namespace Tellico {
 class LineFieldWidget : public FieldWidget {
 Q_OBJECT
 
+friend class ::FieldWidgetTest;
+
 public:
   LineFieldWidget(Data::FieldPtr field, QWidget* parent);
   virtual ~LineFieldWidget() {}
@@ -54,6 +58,8 @@ protected:
   virtual void updateFieldHook(Data::FieldPtr oldField, Data::FieldPtr newField) Q_DECL_OVERRIDE;
 
 private:
+  void createCompletionObject(const QString& fieldName);
+
   GUI::LineEdit* m_lineEdit;
 };
 
