@@ -35,10 +35,12 @@
 #include <QTest>
 #include <QTemporaryDir>
 #include <QFile>
+#include <QStandardPaths>
 
 QTEST_GUILESS_MAIN( DocumentTest )
 
 void DocumentTest::initTestCase() {
+  QStandardPaths::setTestModeEnabled(true);
   Tellico::ImageFactory::init();
   // test case is a book file
   Tellico::RegisterCollection<Tellico::Data::BookCollection> registerBook(Tellico::Data::Collection::Book, "book");
