@@ -27,7 +27,7 @@
 
 #include "abstractfetchertest.h"
 
-#include <KConfig>
+#include <KSharedConfig>
 
 class ISBNdbFetcherTest : public AbstractFetcherTest {
 Q_OBJECT
@@ -44,7 +44,7 @@ private Q_SLOTS:
 
 private:
   bool m_hasConfigFile;
-  KConfig m_config;
+  KSharedConfig::Ptr m_config;
 };
 
 #endif
