@@ -110,7 +110,7 @@ void UPCItemDbFetcherTest::test1632() {
   Tellico::Data::EntryPtr entry = results.at(0);
   QVERIFY(entry);
 
-  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("1632"));
+  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Ring of Fire: 1632"));
   QCOMPARE(entry->field(QStringLiteral("author")), QStringLiteral("Eric Flint"));
   QCOMPARE(entry->field(QStringLiteral("isbn")), QStringLiteral("9780671319724"));
   QCOMPARE(entry->field(QStringLiteral("publisher")), QStringLiteral("Baen"));
@@ -134,7 +134,7 @@ void UPCItemDbFetcherTest::testBurningEdge() {
 
   QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Burning Edge Of Dawn"));
   QCOMPARE(entry->field(QStringLiteral("artist")), QStringLiteral("Andrew Peterson"));
-  QCOMPARE(entry->field(QStringLiteral("label")), QStringLiteral("Centricity Music"));
+  QCOMPARE(entry->field(QStringLiteral("label")), QStringLiteral("UMGD"));
   QCOMPARE(entry->field(QStringLiteral("medium")), QStringLiteral("Compact Disc"));
   QVERIFY(!entry->field(QStringLiteral("cover")).isEmpty());
   QVERIFY(!entry->field(QStringLiteral("cover")).contains(QLatin1Char('/')));
