@@ -56,7 +56,7 @@ public:
   virtual bool canImport(int type) const Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
-  void slotCancel();
+  void slotCancel() Q_DECL_OVERRIDE;
 
 private:
   static void initTagMap();
