@@ -22,6 +22,7 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <config.h>
 #include "bibteximporter.h"
 #include "../utils/bibtexhandler.h"
 #include "../collections/bibtexcollection.h"
@@ -34,7 +35,7 @@
 #include <KSharedConfig>
 #include <KConfigGroup>
 
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QGroupBox>
 #include <QRadioButton>
 #include <QTextCodec>
@@ -46,6 +47,11 @@
 using namespace Tellico;
 using Tellico::Import::BibtexImporter;
 
+#ifndef ENABLE_BTPARSE
+void bt_cleanup() {}
+void bt_initialize() {}
+#endif
+
 int BibtexImporter::s_initCount = 0;
 
 BibtexImporter::BibtexImporter(const QList<QUrl>& urls_) : Importer(urls_)
@@ -130,6 +136,7 @@ Tellico::Data::CollPtr BibtexImporter::collection() {
 }
 
 Tellico::Data::CollPtr BibtexImporter::readCollection(const QString& text, int urlCount) {
+#ifdef ENABLE_BTPARSE
   if(text.isEmpty()) {
     myDebug() << "no text";
     return Data::CollPtr();
@@ -193,6 +200,7 @@ Tellico::Data::CollPtr BibtexImporter::readCollection(const QString& text, int u
 //    myDebug() << "entry key: " << str;
     Data::BibtexCollection::setFieldValue(entry, QStringLiteral("key"), str, currentColl);
 
+    QRegularExpression andRx(QLatin1String("\\sand\\s"));
     char* name;
     AST* field = nullptr;
     while((field = bt_next_field(node, field, &name))) {
@@ -224,7 +232,7 @@ Tellico::Data::CollPtr BibtexImporter::readCollection(const QString& text, int u
       }
       QString fieldName = QString::fromUtf8(name);
       if(fieldName == QLatin1String("author") || fieldName == QLatin1String("editor")) {
-        str.replace(QRegExp(QLatin1String("\\sand\\s")),FieldFormat::delimiterString());
+        str.replace(andRx,FieldFormat::delimiterString());
       }
       // there's a 'key' field different from the citation key
       // https://nwalsh.com/tex/texhelp/bibtx-37.html
@@ -254,9 +262,13 @@ Tellico::Data::CollPtr BibtexImporter::readCollection(const QString& text, int u
   }
 
   return ptr;
+#else
+  return Data::CollPtr();
+#endif // ENABLE_BTPARSE
 }
 
 void BibtexImporter::parseText(const QString& text) {
+#ifdef ENABLE_BTPARSE
   m_nodes.clear();
   m_macros.clear();
 
@@ -269,15 +281,15 @@ void BibtexImporter::parseText(const QString& text) {
 //  bt_set_stringopts(BTE_PREAMBLE, BTO_CONVERT | BTO_EXPAND);
 
   QString entry;
-  QRegExp rx(QLatin1String("[{}]"));
-  QRegExp macroName(QLatin1String("@string\\s*\\{\\s*(.*)="), Qt::CaseInsensitive);
-  macroName.setMinimal(true);
+  QRegularExpression rx(QLatin1String("[{}]"));
+  QRegularExpression macroName(QLatin1String("@string\\s*\\{\\s*(.*?)="), QRegularExpression::CaseInsensitiveOption);
 
   int line = 1;
   bool needsCleanup = false;
   int brace = 0;
   int startpos = 0;
-  int pos = rx.indexIn(text, 0);
+  QRegularExpressionMatch m = rx.match(text);
+  int pos = m.capturedStart();
   while(pos > 0 && !m_cancelled) {
     if(text[pos] == QLatin1Char('{')) {
       ++brace;
@@ -293,10 +305,11 @@ void BibtexImporter::parseText(const QString& text) {
                                    filename.data(),
                                    line, bt_options, &ok);
       if(ok && node) {
-        if(bt_entry_metatype(node) == BTE_MACRODEF && macroName.indexIn(entry) > -1) {
+        QRegularExpressionMatch macroMatch = macroName.match(entry);
+        if(bt_entry_metatype(node) == BTE_MACRODEF && macroMatch.hasMatch()) {
           char* macro;
           (void) bt_next_field(node, nullptr, &macro);
-          m_macros.insert(QString::fromUtf8(macro), macroName.cap(1).trimmed());
+          m_macros.insert(QString::fromUtf8(macro), macroMatch.captured(1).trimmed());
         }
         m_nodes.append(node);
         needsCleanup = true;
@@ -304,12 +317,14 @@ void BibtexImporter::parseText(const QString& text) {
       startpos = pos+1;
       line += entry.count(QLatin1Char('\n'));
     }
-    pos = rx.indexIn(text, pos+1);
+    m = rx.match(text, pos+1);
+    pos = m.capturedStart();
   }
   if(needsCleanup) {
     // clean up some structures
     bt_parse_entry_s(nullptr, nullptr, 1, 0, nullptr);
   }
+#endif // ENABLE_BTPARSE
 }
 
 void BibtexImporter::slotCancel() {
@@ -364,15 +379,17 @@ bool BibtexImporter::maybeBibtex(const QUrl& url_) {
 }
 
 bool BibtexImporter::maybeBibtex(const QString& text, const QUrl& url_) {
+  bool foundOne = false;
+#ifdef ENABLE_BTPARSE
   bt_initialize();
-  QRegExp rx(QLatin1String("[{}]"));
+  QRegularExpression rx(QLatin1String("[{}]"));
 
   ushort bt_options = 0; // ushort is defined in btparse.h
   boolean ok; // boolean is defined in btparse.h as an int
-  bool foundOne = false;
   int brace = 0;
   int startpos = 0;
-  int pos = rx.indexIn(text, 0);
+  QRegularExpressionMatch m = rx.match(text);
+  int pos = m.capturedStart();
   while(pos > 0) {
     if(text[pos] == QLatin1Char('{')) {
       ++brace;
@@ -391,13 +408,15 @@ bool BibtexImporter::maybeBibtex(const QString& text, const QUrl& url_) {
       }
       startpos = pos+1;
     }
-    pos = rx.indexIn(text, pos+1);
+    m = rx.match(text, pos+1);
+    pos = m.capturedStart();
   }
   if(foundOne) {
     // clean up some structures
     bt_parse_entry_s(nullptr, nullptr, 1, 0, nullptr);
   }
   bt_cleanup();
+#endif // ENABLE_BTPARSE
   return foundOne;
 }
 
@@ -419,6 +438,10 @@ void BibtexImporter::appendCollection(Data::CollPtr coll_) {
     mainColl->setPreamble(pre + newColl->preamble());
   }
   StringMap macros = mainColl->macroList();
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
   macros.unite(newColl->macroList());
+#else
+  macros.insert(newColl->macroList());
+#endif
   mainColl->setMacroList(macros);
 }
